# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_search.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_search.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import tile_pb2 as tile__pb2
try:
  common__models__pb2 = tile__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = tile__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.tile_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x61ta_search.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ntile.proto\"4\n\x1a\x44\x61taSearchSchemaGetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"c\n\x1b\x44\x61taSearchSchemaGetResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12,\n\x0bjson_schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xfb\x02\n\x11\x44\x61taSearchRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12.\n\rsearch_params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\x08\x61oi_geom\x18\x03 \x01(\x0cH\x00\x12\x10\n\x06\x61oi_id\x18\x04 \x01(\tH\x00\x12:\n\ntime_range\x18\x05 \x01(\x0b\x32$.oi.papi.DataSearchRequest.TimeRangeH\x01\x12\x10\n\x06toi_id\x18\x06 \x01(\tH\x01\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\x1aj\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07spatialB\n\n\x08temporal\"\x86\x01\n\x12\x44\x61taSearchResponse\x12/\n\x0egeojson_struct\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0egeojson_string\x18\x03 \x01(\t\"\xa5\x01\n%DataSearchDisplayTilesBatchGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12.\n\rsearch_params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\"D\n\rTileSetWithId\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x08tile_set\x18\x02 \x01(\x0b\x32\x15.oi.papi.tile.TileSet\"|\n&DataSearchDisplayTilesBatchGetResponse\x12)\n\ttile_sets\x18\x01 \x03(\x0b\x32\x16.oi.papi.TileSetWithId\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x88\x01\n!DataSearchResourceBatchGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x15\n\rallow_missing\x18\x02 \x01(\x08\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\"~\n\"DataSearchResourceBatchGetResponse\x12/\n\x0egeojson_struct\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\">\n$DataSearchEstimatedSummaryGetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\"L\n\rSummaryByDate\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12,\n\x08unixtime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x85\x01\n%DataSearchEstimatedSummaryGetResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\x04\x12/\n\x0fsummary_by_date\x18\x03 \x03(\x0b\x32\x16.oi.papi.SummaryByDate\"F\n DataSourceGetDownloadLinkRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"^\n!DataSourceGetDownloadLinkResponse\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rdownload_link\x18\x03 \x01(\t2\xf4\x04\n\rDataSearchApi\x12W\n\nget_schema\x12#.oi.papi.DataSearchSchemaGetRequest\x1a$.oi.papi.DataSearchSchemaGetResponse\x12\x41\n\x06search\x12\x1a.oi.papi.DataSearchRequest\x1a\x1b.oi.papi.DataSearchResponse\x12t\n\x11get_display_tiles\x12..oi.papi.DataSearchDisplayTilesBatchGetRequest\x1a/.oi.papi.DataSearchDisplayTilesBatchGetResponse\x12m\n\x12get_resource_batch\x12*.oi.papi.DataSearchResourceBatchGetRequest\x1a+.oi.papi.DataSearchResourceBatchGetResponse\x12v\n\x15get_estimated_summary\x12-.oi.papi.DataSearchEstimatedSummaryGetRequest\x1a..oi.papi.DataSearchEstimatedSummaryGetResponse\x12j\n\x11get_download_link\x12).oi.papi.DataSourceGetDownloadLinkRequest\x1a*.oi.papi.DataSourceGetDownloadLinkResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASEARCHSCHEMAGETREQUEST']._serialized_start=126
  _globals['_DATASEARCHSCHEMAGETREQUEST']._serialized_end=178
  _globals['_DATASEARCHSCHEMAGETRESPONSE']._serialized_start=180
  _globals['_DATASEARCHSCHEMAGETRESPONSE']._serialized_end=279
  _globals['_DATASEARCHREQUEST']._serialized_start=282
  _globals['_DATASEARCHREQUEST']._serialized_end=661
  _globals['_DATASEARCHREQUEST_TIMERANGE']._serialized_start=532
  _globals['_DATASEARCHREQUEST_TIMERANGE']._serialized_end=638
  _globals['_DATASEARCHRESPONSE']._serialized_start=664
  _globals['_DATASEARCHRESPONSE']._serialized_end=798
  _globals['_DATASEARCHDISPLAYTILESBATCHGETREQUEST']._serialized_start=801
  _globals['_DATASEARCHDISPLAYTILESBATCHGETREQUEST']._serialized_end=966
  _globals['_TILESETWITHID']._serialized_start=968
  _globals['_TILESETWITHID']._serialized_end=1036
  _globals['_DATASEARCHDISPLAYTILESBATCHGETRESPONSE']._serialized_start=1038
  _globals['_DATASEARCHDISPLAYTILESBATCHGETRESPONSE']._serialized_end=1162
  _globals['_DATASEARCHRESOURCEBATCHGETREQUEST']._serialized_start=1165
  _globals['_DATASEARCHRESOURCEBATCHGETREQUEST']._serialized_end=1301
  _globals['_DATASEARCHRESOURCEBATCHGETRESPONSE']._serialized_start=1303
  _globals['_DATASEARCHRESOURCEBATCHGETRESPONSE']._serialized_end=1429
  _globals['_DATASEARCHESTIMATEDSUMMARYGETREQUEST']._serialized_start=1431
  _globals['_DATASEARCHESTIMATEDSUMMARYGETREQUEST']._serialized_end=1493
  _globals['_SUMMARYBYDATE']._serialized_start=1495
  _globals['_SUMMARYBYDATE']._serialized_end=1571
  _globals['_DATASEARCHESTIMATEDSUMMARYGETRESPONSE']._serialized_start=1574
  _globals['_DATASEARCHESTIMATEDSUMMARYGETRESPONSE']._serialized_end=1707
  _globals['_DATASOURCEGETDOWNLOADLINKREQUEST']._serialized_start=1709
  _globals['_DATASOURCEGETDOWNLOADLINKREQUEST']._serialized_end=1779
  _globals['_DATASOURCEGETDOWNLOADLINKRESPONSE']._serialized_start=1781
  _globals['_DATASOURCEGETDOWNLOADLINKRESPONSE']._serialized_end=1875
  _globals['_DATASEARCHAPI']._serialized_start=1878
  _globals['_DATASEARCHAPI']._serialized_end=2506
# @@protoc_insertion_point(module_scope)
