# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: filter.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66ilter.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"_\n\x13\x46ilterCreateRequest\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\">\n\x14\x46ilterCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tfilter_id\x18\x02 \x01(\t\"\"\n\x13\x46ilterDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"+\n\x14\x46ilterDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"G\n\x1a\x46ilterMappingCreateRequest\x12\x16\n\x0e\x63omputation_id\x18\x01 \x01(\t\x12\x11\n\tfilter_id\x18\x02 \x01(\t\"2\n\x1b\x46ilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"P\n\x11\x46ilterListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x12\n\ndata_types\x18\x02 \x03(\t\"^\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\"t\n\x12\x46ilterListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12 \n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x0f.oi.papi.Filter\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\xb7\x02\n\tFilterApi\x12\x45\n\x06\x63reate\x12\x1c.oi.papi.FilterCreateRequest\x1a\x1d.oi.papi.FilterCreateResponse\x12\x45\n\x06\x64\x65lete\x12\x1c.oi.papi.FilterDeleteRequest\x1a\x1d.oi.papi.FilterDeleteResponse\x12[\n\x0e\x63reate_mapping\x12#.oi.papi.FilterMappingCreateRequest\x1a$.oi.papi.FilterMappingCreateResponse\x12?\n\x04list\x12\x1a.oi.papi.FilterListRequest\x1a\x1b.oi.papi.FilterListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FILTERCREATEREQUEST']._serialized_start=46
  _globals['_FILTERCREATEREQUEST']._serialized_end=141
  _globals['_FILTERCREATERESPONSE']._serialized_start=143
  _globals['_FILTERCREATERESPONSE']._serialized_end=205
  _globals['_FILTERDELETEREQUEST']._serialized_start=207
  _globals['_FILTERDELETEREQUEST']._serialized_end=241
  _globals['_FILTERDELETERESPONSE']._serialized_start=243
  _globals['_FILTERDELETERESPONSE']._serialized_end=286
  _globals['_FILTERMAPPINGCREATEREQUEST']._serialized_start=288
  _globals['_FILTERMAPPINGCREATEREQUEST']._serialized_end=359
  _globals['_FILTERMAPPINGCREATERESPONSE']._serialized_start=361
  _globals['_FILTERMAPPINGCREATERESPONSE']._serialized_end=411
  _globals['_FILTERLISTREQUEST']._serialized_start=413
  _globals['_FILTERLISTREQUEST']._serialized_end=493
  _globals['_FILTER']._serialized_start=495
  _globals['_FILTER']._serialized_end=589
  _globals['_FILTERLISTRESPONSE']._serialized_start=591
  _globals['_FILTERLISTRESPONSE']._serialized_end=707
  _globals['_FILTERAPI']._serialized_start=710
  _globals['_FILTERAPI']._serialized_end=1021
# @@protoc_insertion_point(module_scope)
