# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61nalysis.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"U\n\x15\x41nalysisAlgorithmNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1c\n\x14\x61lgorithm_version_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\"5\n\x15\x41nalysisCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\"R\n\x16\x41nalysisCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalysis\x18\x02 \x01(\x0b\x32\x11.oi.papi.Analysis\"H\n\x1b\x41nalysisAlgorithmConfigNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1b\n\x13\x61lgorithm_config_id\x18\x02 \x01(\t\"J\n\x12\x41nalysisGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"d\n\x08\x41nalysis\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\"x\n\x13\x41nalysisGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalyses\x18\x02 \x03(\x0b\x32\x11.oi.papi.Analysis\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xbb\x01\n\x13\x41nalysisListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"y\n\x14\x41nalysisListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12#\n\x08\x61nalyses\x18\x02 \x03(\x0b\x32\x11.oi.papi.Analysis\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\xdf\x01\n\x0b\x41nalysisApi\x12I\n\x06\x63reate\x12\x1e.oi.papi.AnalysisCreateRequest\x1a\x1f.oi.papi.AnalysisCreateResponse\x12@\n\x03get\x12\x1b.oi.papi.AnalysisGetRequest\x1a\x1c.oi.papi.AnalysisGetResponse\x12\x43\n\x04list\x12\x1c.oi.papi.AnalysisListRequest\x1a\x1d.oi.papi.AnalysisListResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISALGORITHMNODE']._serialized_start=81
  _globals['_ANALYSISALGORITHMNODE']._serialized_end=166
  _globals['_ANALYSISCREATEREQUEST']._serialized_start=168
  _globals['_ANALYSISCREATEREQUEST']._serialized_end=221
  _globals['_ANALYSISCREATERESPONSE']._serialized_start=223
  _globals['_ANALYSISCREATERESPONSE']._serialized_end=305
  _globals['_ANALYSISALGORITHMCONFIGNODE']._serialized_start=307
  _globals['_ANALYSISALGORITHMCONFIGNODE']._serialized_end=379
  _globals['_ANALYSISGETREQUEST']._serialized_start=381
  _globals['_ANALYSISGETREQUEST']._serialized_end=455
  _globals['_ANALYSIS']._serialized_start=457
  _globals['_ANALYSIS']._serialized_end=557
  _globals['_ANALYSISGETRESPONSE']._serialized_start=559
  _globals['_ANALYSISGETRESPONSE']._serialized_end=679
  _globals['_ANALYSISLISTREQUEST']._serialized_start=682
  _globals['_ANALYSISLISTREQUEST']._serialized_end=869
  _globals['_ANALYSISLISTRESPONSE']._serialized_start=871
  _globals['_ANALYSISLISTRESPONSE']._serialized_end=992
  _globals['_ANALYSISAPI']._serialized_start=995
  _globals['_ANALYSISAPI']._serialized_end=1218
# @@protoc_insertion_point(module_scope)
