# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: system.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'system.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csystem.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\"\r\n\x0bPingRequest\"#\n\x0cPingResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x1c\n\x1aPingRequestServerStreaming\"A\n\x1bPingResponseServerStreaming\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r2\xc8\x01\n\tSystemApi\x12T\n\x08get_ping\x12\x14.oi.papi.PingRequest\x1a\x15.oi.papi.PingResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/systemapi/get_ping\x12\x65\n\x16get_ping_server_stream\x12#.oi.papi.PingRequestServerStreaming\x1a$.oi.papi.PingResponseServerStreaming0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'system_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSTEMAPI'].methods_by_name['get_ping']._loaded_options = None
  _globals['_SYSTEMAPI'].methods_by_name['get_ping']._serialized_options = b'\202\323\344\223\002\025\022\023/systemapi/get_ping'
  _globals['_PINGREQUEST']._serialized_start=55
  _globals['_PINGREQUEST']._serialized_end=68
  _globals['_PINGRESPONSE']._serialized_start=70
  _globals['_PINGRESPONSE']._serialized_end=105
  _globals['_PINGREQUESTSERVERSTREAMING']._serialized_start=107
  _globals['_PINGREQUESTSERVERSTREAMING']._serialized_end=135
  _globals['_PINGRESPONSESERVERSTREAMING']._serialized_start=137
  _globals['_PINGRESPONSESERVERSTREAMING']._serialized_end=202
  _globals['_SYSTEMAPI']._serialized_start=205
  _globals['_SYSTEMAPI']._serialized_end=405
# @@protoc_insertion_point(module_scope)
