# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_collection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'user_collection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import user_pb2 as user__pb2
try:
  common__models__pb2 = user__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = user__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.user_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15user_collection.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\nuser.proto\"\x94\x01\n\x0eUserCollection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x05users\x18\x03 \x03(\x0b\x32\r.oi.papi.User\"J\n\x0cWellKnownIds\x12\x1b\n\x17USER_COLLECTION_UNKNOWN\x10\x00\x12\x1d\n\x19USER_COLLECTION_ID_PUBLIC\x10\x01\"J\n\x1bUserCollectionCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15parent_collection_ids\x18\x02 \x03(\t\"`\n\x1cUserCollectionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"^\n\x18UserCollectionGetRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\x12\x15\n\rinclude_users\x18\x02 \x01(\x08\"]\n\x19UserCollectionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12+\n\ncollection\x18\x02 \x01(\x0b\x32\x17.oi.papi.UserCollection\"J\n\x1bUserCollectionUpdateRequest\x12+\n\ncollection\x18\x01 \x01(\x0b\x32\x17.oi.papi.UserCollection\"3\n\x1cUserCollectionUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"4\n\x1bUserCollectionDeleteRequest\x12\x15\n\rcollection_id\x18\x01 \x01(\t\"3\n\x1cUserCollectionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"F\n\x1cUserCollectionAddUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x15\n\rcollection_id\x18\x02 \x01(\t\"4\n\x1dUserCollectionAddUserResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"I\n\x1fUserCollectionRemoveUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x15\n\rcollection_id\x18\x02 \x01(\t\"7\n UserCollectionRemoveUserResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xae\x03\n\x19UserCollectionListRequest\x12\x1c\n\x14parent_collection_id\x18\x01 \x01(\t\x12N\n\x0f\x63ollection_type\x18\x02 \x01(\x0e\x32\x35.oi.papi.UserCollectionListRequest.UserCollectionType\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x18\n\x10max_search_depth\x18\x04 \x01(\x05\x12\x15\n\rinclude_users\x18\x05 \x01(\x08\"\xdc\x01\n\x12UserCollectionType\x12 \n\x1cUNKNOWN_USER_COLLECTION_TYPE\x10\x00\x12\x1c\n\x18USER_COLLECTION_TYPE_ANY\x10\x01\x12!\n\x1dUSER_COLLECTION_TYPE_CUSTOMER\x10\x02\x12#\n\x1fUSER_COLLECTION_TYPE_DEPARTMENT\x10\x03\x12\x1d\n\x19USER_COLLECTION_TYPE_USER\x10\x04\x12\x1f\n\x1bUSER_COLLECTION_TYPE_ADMINS\x10\x05\"_\n\x1aUserCollectionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32\x17.oi.papi.UserCollection2\xf6\x04\n\x11UserCollectionApi\x12U\n\x06\x63reate\x12$.oi.papi.UserCollectionCreateRequest\x1a%.oi.papi.UserCollectionCreateResponse\x12L\n\x03get\x12!.oi.papi.UserCollectionGetRequest\x1a\".oi.papi.UserCollectionGetResponse\x12O\n\x04list\x12\".oi.papi.UserCollectionListRequest\x1a#.oi.papi.UserCollectionListResponse\x12U\n\x06update\x12$.oi.papi.UserCollectionUpdateRequest\x1a%.oi.papi.UserCollectionUpdateResponse\x12U\n\x06\x64\x65lete\x12$.oi.papi.UserCollectionDeleteRequest\x1a%.oi.papi.UserCollectionDeleteResponse\x12Y\n\x08\x61\x64\x64_user\x12%.oi.papi.UserCollectionAddUserRequest\x1a&.oi.papi.UserCollectionAddUserResponse\x12\x62\n\x0bremove_user\x12(.oi.papi.UserCollectionRemoveUserRequest\x1a).oi.papi.UserCollectionRemoveUserResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_collection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USERCOLLECTION']._serialized_start=68
  _globals['_USERCOLLECTION']._serialized_end=216
  _globals['_USERCOLLECTION_WELLKNOWNIDS']._serialized_start=142
  _globals['_USERCOLLECTION_WELLKNOWNIDS']._serialized_end=216
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_start=218
  _globals['_USERCOLLECTIONCREATEREQUEST']._serialized_end=292
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_start=294
  _globals['_USERCOLLECTIONCREATERESPONSE']._serialized_end=390
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_start=392
  _globals['_USERCOLLECTIONGETREQUEST']._serialized_end=486
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_start=488
  _globals['_USERCOLLECTIONGETRESPONSE']._serialized_end=581
  _globals['_USERCOLLECTIONUPDATEREQUEST']._serialized_start=583
  _globals['_USERCOLLECTIONUPDATEREQUEST']._serialized_end=657
  _globals['_USERCOLLECTIONUPDATERESPONSE']._serialized_start=659
  _globals['_USERCOLLECTIONUPDATERESPONSE']._serialized_end=710
  _globals['_USERCOLLECTIONDELETEREQUEST']._serialized_start=712
  _globals['_USERCOLLECTIONDELETEREQUEST']._serialized_end=764
  _globals['_USERCOLLECTIONDELETERESPONSE']._serialized_start=766
  _globals['_USERCOLLECTIONDELETERESPONSE']._serialized_end=817
  _globals['_USERCOLLECTIONADDUSERREQUEST']._serialized_start=819
  _globals['_USERCOLLECTIONADDUSERREQUEST']._serialized_end=889
  _globals['_USERCOLLECTIONADDUSERRESPONSE']._serialized_start=891
  _globals['_USERCOLLECTIONADDUSERRESPONSE']._serialized_end=943
  _globals['_USERCOLLECTIONREMOVEUSERREQUEST']._serialized_start=945
  _globals['_USERCOLLECTIONREMOVEUSERREQUEST']._serialized_end=1018
  _globals['_USERCOLLECTIONREMOVEUSERRESPONSE']._serialized_start=1020
  _globals['_USERCOLLECTIONREMOVEUSERRESPONSE']._serialized_end=1075
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_start=1078
  _globals['_USERCOLLECTIONLISTREQUEST']._serialized_end=1508
  _globals['_USERCOLLECTIONLISTREQUEST_USERCOLLECTIONTYPE']._serialized_start=1288
  _globals['_USERCOLLECTIONLISTREQUEST_USERCOLLECTIONTYPE']._serialized_end=1508
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_start=1510
  _globals['_USERCOLLECTIONLISTRESPONSE']._serialized_end=1605
  _globals['_USERCOLLECTIONAPI']._serialized_start=1608
  _globals['_USERCOLLECTIONAPI']._serialized_end=2238
# @@protoc_insertion_point(module_scope)
