# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_collaborator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'project_collaborator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aproject_collaborator.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"\xd5\x01\n\x13ProjectCollaborator\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x36\n\x04role\x18\x02 \x01(\x0e\x32(.oi.papi.ProjectCollaborator.ProjectRole\x12\x13\n\x0b\x63ustomer_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"R\n\x0bProjectRole\x12\x18\n\x14UNKNOWN_PROJECT_ROLE\x10\x00\x12\x0b\n\x07\x43REATOR\x10\x01\x12\x10\n\x0c\x43OLLABORATOR\x10\x02\x12\n\n\x06VIEWER\x10\x03\"3\n\x1dProjectCollaboratorGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"r\n\x1eProjectCollaboratorGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"s\n ProjectCollaboratorUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12;\n\x15project_collaborators\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectCollaborator\"8\n!ProjectCollaboratorUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n ProjectCollaboratorDeleteRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08user_ids\x18\x02 \x03(\t\"8\n!ProjectCollaboratorDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb2\x02\n\x16ProjectCollaboratorApi\x12V\n\x03get\x12&.oi.papi.ProjectCollaboratorGetRequest\x1a\'.oi.papi.ProjectCollaboratorGetResponse\x12_\n\x06update\x12).oi.papi.ProjectCollaboratorUpdateRequest\x1a*.oi.papi.ProjectCollaboratorUpdateResponse\x12_\n\x06\x64\x65lete\x12).oi.papi.ProjectCollaboratorDeleteRequest\x1a*.oi.papi.ProjectCollaboratorDeleteResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_collaborator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTCOLLABORATOR']._serialized_start=61
  _globals['_PROJECTCOLLABORATOR']._serialized_end=274
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_start=192
  _globals['_PROJECTCOLLABORATOR_PROJECTROLE']._serialized_end=274
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_start=276
  _globals['_PROJECTCOLLABORATORGETREQUEST']._serialized_end=327
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_start=329
  _globals['_PROJECTCOLLABORATORGETRESPONSE']._serialized_end=443
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_start=445
  _globals['_PROJECTCOLLABORATORUPDATEREQUEST']._serialized_end=560
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_start=562
  _globals['_PROJECTCOLLABORATORUPDATERESPONSE']._serialized_end=618
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_start=620
  _globals['_PROJECTCOLLABORATORDELETEREQUEST']._serialized_end=692
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_start=694
  _globals['_PROJECTCOLLABORATORDELETERESPONSE']._serialized_end=750
  _globals['_PROJECTCOLLABORATORAPI']._serialized_start=753
  _globals['_PROJECTCOLLABORATORAPI']._serialized_end=1059
# @@protoc_insertion_point(module_scope)
