# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: token.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'token.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btoken.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"C\n\x12TokenCreateRequest\x12\x18\n\x10\x64uration_minutes\x18\x01 \x01(\x05\x12\x13\n\x0b\x66or_user_id\x18\x02 \x01(\t\"=\n\x13TokenCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t2O\n\x08TokenApi\x12\x43\n\x06\x63reate\x12\x1b.oi.papi.TokenCreateRequest\x1a\x1c.oi.papi.TokenCreateResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'token_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENCREATEREQUEST']._serialized_start=45
  _globals['_TOKENCREATEREQUEST']._serialized_end=112
  _globals['_TOKENCREATERESPONSE']._serialized_start=114
  _globals['_TOKENCREATERESPONSE']._serialized_end=175
  _globals['_TOKENAPI']._serialized_start=177
  _globals['_TOKENAPI']._serialized_end=256
# @@protoc_insertion_point(module_scope)
