# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis_version.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'analysis_version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2
from terrascope_api.models import algorithm_version_pb2 as algorithm__version__pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__version__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__version__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_pb2 import *
from terrascope_api.models.algorithm_version_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61nalysis_version.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0e\x61nalysis.proto\x1a\x17\x61lgorithm_version.proto\"\xdb\x01\n\x10\x41nalysisManifest\x12\x18\n\x10manifest_version\x18\x01 \x01(\t\x12\x34\n\x08metadata\x18\x02 \x01(\x0b\x32\".oi.papi.AnalysisManifest.Metadata\x12\x37\n\x0f\x61lgorithm_nodes\x18\x03 \x03(\x0b\x32\x1e.oi.papi.AnalysisAlgorithmNode\x1a>\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xdf\x01\n\x0f\x41nalysisVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x08\x61nalysis\x18\x02 \x01(\x0b\x32\x11.oi.papi.Analysis\x12\x34\n\x11\x61nalysis_manifest\x18\x03 \x01(\x0b\x32\x19.oi.papi.AnalysisManifest\x12.\n\ncreated_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12\x61lgorithm_versions\x18\x05 \x03(\x0b\x32\x19.oi.papi.AlgorithmVersion\"i\n\x1c\x41nalysisVersionCreateRequest\x12\x13\n\x0b\x61nalysis_id\x18\x01 \x01(\t\x12\x34\n\x11\x61nalysis_manifest\x18\x02 \x01(\x0b\x32\x19.oi.papi.AnalysisManifest\"h\n\x1d\x41nalysisVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x32\n\x10\x61nalysis_version\x18\x02 \x01(\x0b\x32\x18.oi.papi.AnalysisVersion\"\x8e\x01\n\x19\x41nalysisVersionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x18\n\x10include_manifest\x18\x02 \x01(\x08\x12!\n\x19include_algorithm_details\x18\x03 \x01(\x08\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x8f\x01\n\x1a\x41nalysisVersionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61nalysis_versions\x18\x02 \x03(\x0b\x32\x18.oi.papi.AnalysisVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x9c\x02\n\x1a\x41nalysisVersionListRequest\x12\x13\n\x0b\x61nalysis_id\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x32\n\x0emin_created_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10include_manifest\x18\x06 \x01(\x08\x12\x1c\n\x14include_all_versions\x18\x07 \x01(\x08\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x90\x01\n\x1b\x41nalysisVersionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61nalysis_versions\x18\x02 \x03(\x0b\x32\x18.oi.papi.AnalysisVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x90\x02\n\x12\x41nalysisVersionApi\x12W\n\x06\x63reate\x12%.oi.papi.AnalysisVersionCreateRequest\x1a&.oi.papi.AnalysisVersionCreateResponse\x12N\n\x03get\x12\".oi.papi.AnalysisVersionGetRequest\x1a#.oi.papi.AnalysisVersionGetResponse\x12Q\n\x04list\x12#.oi.papi.AnalysisVersionListRequest\x1a$.oi.papi.AnalysisVersionListResponseP\x01P\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISMANIFEST']._serialized_start=131
  _globals['_ANALYSISMANIFEST']._serialized_end=350
  _globals['_ANALYSISMANIFEST_METADATA']._serialized_start=288
  _globals['_ANALYSISMANIFEST_METADATA']._serialized_end=350
  _globals['_ANALYSISVERSION']._serialized_start=353
  _globals['_ANALYSISVERSION']._serialized_end=576
  _globals['_ANALYSISVERSIONCREATEREQUEST']._serialized_start=578
  _globals['_ANALYSISVERSIONCREATEREQUEST']._serialized_end=683
  _globals['_ANALYSISVERSIONCREATERESPONSE']._serialized_start=685
  _globals['_ANALYSISVERSIONCREATERESPONSE']._serialized_end=789
  _globals['_ANALYSISVERSIONGETREQUEST']._serialized_start=792
  _globals['_ANALYSISVERSIONGETREQUEST']._serialized_end=934
  _globals['_ANALYSISVERSIONGETRESPONSE']._serialized_start=937
  _globals['_ANALYSISVERSIONGETRESPONSE']._serialized_end=1080
  _globals['_ANALYSISVERSIONLISTREQUEST']._serialized_start=1083
  _globals['_ANALYSISVERSIONLISTREQUEST']._serialized_end=1367
  _globals['_ANALYSISVERSIONLISTRESPONSE']._serialized_start=1370
  _globals['_ANALYSISVERSIONLISTRESPONSE']._serialized_end=1514
  _globals['_ANALYSISVERSIONAPI']._serialized_start=1517
  _globals['_ANALYSISVERSIONAPI']._serialized_end=1789
# @@protoc_insertion_point(module_scope)
