# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_tracking.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x64\x61ta_tracking.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"T\n\x05Links\x12\x0c\n\x04href\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03rel\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\"7\n\tParentRef\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xd5\x01\n\x0cTrackedEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61ta_tracking_id\x18\x02 \x01(\t\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\x36\n\x12received_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08\x63ontents\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe6\x01\n\x07JobInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x33\n\x0flast_updated_ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\nparent_ref\x18\x07 \x01(\x0b\x32\x12.oi.papi.ParentRef\x12\x13\n\x0bprovider_id\x18\x08 \x01(\t\"h\n\x14TrackedStatusHistory\x12\x18\n\x10\x64\x61ta_tracking_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12&\n\x02ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd1\x01\n\nTrackedJob\x12&\n\nparent_ref\x18\x01 \x01(\x0b\x32\x12.oi.papi.ParentRef\x12\x1e\n\x04info\x18\x02 \x01(\x0b\x32\x10.oi.papi.JobInfo\x12%\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x15.oi.papi.TrackedEvent\x12\x35\n\x0estatus_history\x18\x04 \x03(\x0b\x32\x1d.oi.papi.TrackedStatusHistory\x12\x1d\n\x05links\x18\x05 \x03(\x0b\x32\x0e.oi.papi.Links\"\"\n DataTrackingGetQueryablesRequest\"P\n!DataTrackingGetQueryablesResponse\x12+\n\nqueryables\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x85\x01\n#DataTrackingTrackedJobSearchRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x13\n\x0b\x66ilter_lang\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x10\n\x08order_by\x18\x04 \x01(\t\"r\n$DataTrackingTrackedJobSearchResponse\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12!\n\x04jobs\x18\x02 \x03(\x0b\x32\x13.oi.papi.TrackedJob2\xf2\x01\n\x0f\x44\x61taTrackingApi\x12g\n\x0eget_queryables\x12).oi.papi.DataTrackingGetQueryablesRequest\x1a*.oi.papi.DataTrackingGetQueryablesResponse\x12v\n\x17get_search_tracked_jobs\x12,.oi.papi.DataTrackingTrackedJobSearchRequest\x1a-.oi.papi.DataTrackingTrackedJobSearchResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LINKS']._serialized_start=116
  _globals['_LINKS']._serialized_end=200
  _globals['_PARENTREF']._serialized_start=202
  _globals['_PARENTREF']._serialized_end=257
  _globals['_TRACKEDEVENT']._serialized_start=260
  _globals['_TRACKEDEVENT']._serialized_end=473
  _globals['_JOBINFO']._serialized_start=476
  _globals['_JOBINFO']._serialized_end=706
  _globals['_TRACKEDSTATUSHISTORY']._serialized_start=708
  _globals['_TRACKEDSTATUSHISTORY']._serialized_end=812
  _globals['_TRACKEDJOB']._serialized_start=815
  _globals['_TRACKEDJOB']._serialized_end=1024
  _globals['_DATATRACKINGGETQUERYABLESREQUEST']._serialized_start=1026
  _globals['_DATATRACKINGGETQUERYABLESREQUEST']._serialized_end=1060
  _globals['_DATATRACKINGGETQUERYABLESRESPONSE']._serialized_start=1062
  _globals['_DATATRACKINGGETQUERYABLESRESPONSE']._serialized_end=1142
  _globals['_DATATRACKINGTRACKEDJOBSEARCHREQUEST']._serialized_start=1145
  _globals['_DATATRACKINGTRACKEDJOBSEARCHREQUEST']._serialized_end=1278
  _globals['_DATATRACKINGTRACKEDJOBSEARCHRESPONSE']._serialized_start=1280
  _globals['_DATATRACKINGTRACKEDJOBSEARCHRESPONSE']._serialized_end=1394
  _globals['_DATATRACKINGAPI']._serialized_start=1397
  _globals['_DATATRACKINGAPI']._serialized_end=1639
# @@protoc_insertion_point(module_scope)
