# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_source.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import data_type_pb2 as data__type__pb2

from terrascope_api.models.data_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x61ta_source.proto\x12\x07oi.papi\x1a\x0f\x64\x61ta_type.proto\"\xc0\x01\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12%\n\ndata_types\x18\x04 \x03(\x0b\x32\x11.oi.papi.DataType\x12\x1c\n\x14\x64\x65livery_lag_seconds\x18\x05 \x01(\x04\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\x11\n\tindicator\x18\x07 \x01(\t\x12\x15\n\rdata_explorer\x18\x08 \x01(\x08\"#\n\x14\x44\x61taSourceGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"W\n\x15\x44\x61taSourceGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource\",\n\x15\x44\x61taSourceListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"X\n\x16\x44\x61taSourceListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource2\x9e\x01\n\rDataSourceAPI\x12\x44\n\x03get\x12\x1d.oi.papi.DataSourceGetRequest\x1a\x1e.oi.papi.DataSourceGetResponse\x12G\n\x04list\x12\x1e.oi.papi.DataSourceListRequest\x1a\x1f.oi.papi.DataSourceListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASOURCE']._serialized_start=48
  _globals['_DATASOURCE']._serialized_end=240
  _globals['_DATASOURCEGETREQUEST']._serialized_start=242
  _globals['_DATASOURCEGETREQUEST']._serialized_end=277
  _globals['_DATASOURCEGETRESPONSE']._serialized_start=279
  _globals['_DATASOURCEGETRESPONSE']._serialized_end=366
  _globals['_DATASOURCELISTREQUEST']._serialized_start=368
  _globals['_DATASOURCELISTREQUEST']._serialized_end=412
  _globals['_DATASOURCELISTRESPONSE']._serialized_start=414
  _globals['_DATASOURCELISTRESPONSE']._serialized_end=502
  _globals['_DATASOURCEAPI']._serialized_start=505
  _globals['_DATASOURCEAPI']._serialized_end=663
# @@protoc_insertion_point(module_scope)
