# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import project_aoi_pb2 as project__aoi__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in project_aoi_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ProjectAOIApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/create',
                request_serializer=project__aoi__pb2.ProjectAOICreateRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOICreateResponse.FromString,
                _registered_method=True)
        self.upload = channel.stream_unary(
                '/oi.papi.ProjectAOIApi/upload',
                request_serializer=project__aoi__pb2.ProjectAOIUploadRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIFileUploadResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/delete',
                request_serializer=project__aoi__pb2.ProjectAOIDeleteRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIDeleteResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/get',
                request_serializer=project__aoi__pb2.ProjectAOIGetRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIGetResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/update',
                request_serializer=project__aoi__pb2.ProjectAOIUpdateRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIUpdateResponse.FromString,
                _registered_method=True)


class ProjectAOIApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upload(self, request_iterator, context):
        """
        Upload AOIs to Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectAOIApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=project__aoi__pb2.ProjectAOICreateRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOICreateResponse.SerializeToString,
            ),
            'upload': grpc.stream_unary_rpc_method_handler(
                    servicer.upload,
                    request_deserializer=project__aoi__pb2.ProjectAOIUploadRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIFileUploadResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=project__aoi__pb2.ProjectAOIDeleteRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIDeleteResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=project__aoi__pb2.ProjectAOIGetRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIGetResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=project__aoi__pb2.ProjectAOIUpdateRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.ProjectAOIApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.ProjectAOIApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectAOIApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/create',
            project__aoi__pb2.ProjectAOICreateRequest.SerializeToString,
            project__aoi__pb2.ProjectAOICreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/oi.papi.ProjectAOIApi/upload',
            project__aoi__pb2.ProjectAOIUploadRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIFileUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/delete',
            project__aoi__pb2.ProjectAOIDeleteRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/get',
            project__aoi__pb2.ProjectAOIGetRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/update',
            project__aoi__pb2.ProjectAOIUpdateRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
